# Pylint-Ignore

**WARNING: This file is programatically generated.**

This file is parsed by [`pylint-ignore`](https://pypi.org/project/pylint-ignore/)
to determine which
[Pylint messages](https://pylint.pycqa.org/en/stable/technical_reference/features.html)
should be ignored.

- Do not edit this file manually.
- To update, use `pylint-ignore --update-ignorefile`

The recommended approach to using `pylint-ignore` is:

1. If a message refers to a valid issue, update your code rather than
   ignoring the message.
2. If a message should *always* be ignored (globally), then to do so
   via the usual `pylintrc` or `setup.cfg` files rather than this
   `pylint-ignore.md` file.
3. If a message is a false positive, add a comment of this form to your code:
   `# pylint:disable=<symbol> ; explain why this is a false positive`


# Overview

 - [E0102: function-redefined (2x)](#e0102-function-redefined)
 - [E0602: undefined-variable (4x)](#e0602-undefined-variable)
 - [C0103: invalid-name (2x)](#c0103-invalid-name)
 - [C0303: trailing-whitespace (1x)](#c0303-trailing-whitespace)

# E0102: function-redefined

## File fixtures/fixture_1.py - Line 4 - E0102 (function-redefined)

- `message: function already defined line 1`
- `author : Manuel Barkhau <mbarkhau@gmail.com>`
- `date   : 2020-07-25T18:38:38`

```
  2:     return 1
  3:
> 4: def function_redefined():
  5:     return 1
  6:
```


## File fixtures/fixture_2.py - Line 4 - E0102 (function-redefined)

- `message: function already defined line 1`
- `author : Manuel Barkhau <mbarkhau@gmail.com>`
- `date   : 2020-07-25T18:38:38`

```
  2:     return 1
  3:
> 4: def function_redefined():
  5:     return 1
  6:
```


# E0602: undefined-variable

## File fixtures/fixture_1.py - Line 10 - E0602 (undefined-variable)

- `message: Undefined variable 'Entry'`
- `author : Manuel Barkhau <mbarkhau@gmail.com>`
- `date   : 2020-07-25T18:38:38`

```
   7: def code_duplication():
  ...
   8:     msg_id_count = {}
   9:
> 10:     def _entry_sort_key(e: Entry):
  11:         frequency = -msg_id_count[e.msg_id]
  12:         return frequency, e.msg_id
```


## File fixtures/fixture_2.py - Line 10 - E0602 (undefined-variable)

- `message: Undefined variable 'Entry'`
- `author : Manuel Barkhau <mbarkhau@gmail.com>`
- `date   : 2020-07-25T18:38:38`

```
   7: def code_duplication():
  ...
   8:     msg_id_count = {}
   9:
> 10:     def _entry_sort_key(e: Entry):
  11:         frequency = -msg_id_count[e.msg_id]
  12:         return frequency, e.msg_id
```


## File fixtures/fixture_1.py - Line 14 - E0602 (undefined-variable)

- `message: Undefined variable 'entries'`
- `author : Manuel Barkhau <mbarkhau@gmail.com>`
- `date   : 2020-07-25T18:38:38`

```
   7: def code_duplication():
  ...
  12:         return frequency, e.msg_id
  13:
> 14:     return sorted(entries, key=_entry_sort_key)
```


## File fixtures/fixture_2.py - Line 14 - E0602 (undefined-variable)

- `message: Undefined variable 'entries'`
- `author : Manuel Barkhau <mbarkhau@gmail.com>`
- `date   : 2020-07-25T18:38:38`

```
   7: def code_duplication():
  ...
  12:         return frequency, e.msg_id
  13:
> 14:     return sorted(entries, key=_entry_sort_key)
```


# C0103: invalid-name

## File fixtures/fixture_1.py - Line 10 - C0103 (invalid-name)

- `message: Argument name "e" doesn't conform to snake_case naming style`
- `author : Manuel Barkhau <mbarkhau@gmail.com>`
- `date   : 2020-07-25T18:38:38`

```
   7: def code_duplication():
  ...
   8:     msg_id_count = {}
   9:
> 10:     def _entry_sort_key(e: Entry):
  11:         frequency = -msg_id_count[e.msg_id]
  12:         return frequency, e.msg_id
```


## File fixtures/fixture_2.py - Line 10 - C0103 (invalid-name)

- `message: Argument name "e" doesn't conform to snake_case naming style`
- `author : Manuel Barkhau <mbarkhau@gmail.com>`
- `date   : 2020-07-25T18:38:38`

```
   7: def code_duplication():
  ...
   8:     msg_id_count = {}
   9:
> 10:     def _entry_sort_key(e: Entry):
  11:         frequency = -msg_id_count[e.msg_id]
  12:         return frequency, e.msg_id
```


# C0303: trailing-whitespace

## File fixtures/fixture_3.py - Line 2 - C0303 (trailing-whitespace)

- `message: Trailing whitespace`
- `author : Manuel Barkhau <mbarkhau@gmail.com>`
- `date   : 2021-06-24T16:20:28`

```
  1: def repro():
> 2:    
  3:    return
```